@@ -33,6 +33,11 @@
         <source>Share</source>
         <translation>Jaa</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Change icon</source>
+        <translation>Vaihda kuvake</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Compress</source>
@@ -76,7 +81,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="10"/>
         <source>Cannot create symlink in this folder</source>
-        <translation>No se puede crear el enlace en esta carpeta</translation>
+        <translation>Hakemistoon ei voitu luoda symbolista linkkiä</translation>
     </message>
     <message>
         <location filename="../error.cpp" line="10"/>
@@ -127,7 +132,7 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Symlink destination</source>
-        <translation>Destino del enlace</translation>
+        <translation>Symbolisen linkin kohde</translation>
     </message>
 </context>
 <context>
@@ -186,7 +191,7 @@
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Create new symlink</source>
-        <translation>Crear nuevo enlace</translation>
+        <translation>Luo uusi symbolinen linkki</translation>
     </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
@@ -688,7 +693,7 @@
     </message>
     <message>
         <location filename="../newdoc.cpp" line="10"/>
-        <source>Cancel</source>
+                <source>Cancel</source>
         <translation>Peru</translation>
     </message>
     <message>
@@ -826,7 +831,7 @@
 </context>
 <context>
     <name>UnzipDlg</name>
-    <message>
+        <message>
         <location filename="../unzipdlg.cpp" line="10"/>
         <source>Extract</source>
         <translation>Pura</translation>
@@ -903,4 +908,12 @@
         <translation>Tiedostoselain Maemo 5:lle</translation>
     </message>
 </context>
+<context>
+    <name>selectIcon</name>
+    <message>
+        <location filename="../selecticon.cpp" line="10"/>
+        <source>Select icon</source>
+        <translation>Valitse kuvake</translation>
+    </message>
+</context>
 </TS>
